==> owncloud-9.0.3.tgz: owncloud/lib/l10n/ast.js <==
OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "¡Nun pue escribise nel direutoriu \"config\"!",
    "This can usually be fixed by giving the webserver write access to the config directory" : "Davezu esto pue iguase dándo-y al sirvidor web accesu d'escritura al direutoriu de configuración",
    "See %s" : "Mira %s",
    "This can usually be fixed by %sgiving the webserver write access to the config directory%s." : "Davezu esto pue iguase %sdándo-y al sirvidor web accesu d'escritura al direutoriu de configuración%s.",
    "Sample configuration detected" : "Configuración d'amuesa detectada",
    "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Detectose que la configuración d'amuesa copiose. Esto pue encaboxar la instalación y dexala ensín soporte. Llee la documentación enantes de facer cambéos en config.php",
    "PHP %s or higher is required." : "Necesítase PHP %s o superior",
    "PHP with a version lower than %s is required." : "Necesítase una versión PHP anterior a %s",
    "Following databases are supported: %s" : "Les siguientes bases de datos tan sofitaes: %s",
    "The command line tool %s could not be found" : "La ferramienta línea de comandu %s nun pudo alcontrase",
    "The library %s is not available." : "La librería %s nun ta disponible",
    "Library %s with a version higher than %s is required - available version %s." : "Necesítase una librería %s con ua versión superior a %s - versión disponible %s.",
    "Library %s with a version lower than %s is required - available version %s." : "Necesítase una librería %s con una versión anterior a %s - versión disponible %s.",
    "Following platforms are supported: %s" : "Les siguientes plataformes tan sofitaes: %s",
    "ownCloud %s or higher is required." : "Necesítase ownCloud %s o superior.",
    "ownCloud %s or lower is required." : "Necesítase ownCloud %s o anterior.",
    "Help" : "Ayuda",
    "Personal" : "Personal",
    "Users" : "Usuarios",
    "Admin" : "Almin",
    "Recommended" : "Recomendáu",
    "No app name specified" : "Nun s'especificó nome de l'aplicación",
    "Unknown filetype" : "Triba de ficheru desconocida",
    "Invalid image" : "Imaxe inválida",
    "today" : "güei",
    "yesterday" : "ayeri",
    "last month" : "mes caberu",
    "_%n month ago_::_%n months ago_" : ["hai %n mes","hai %n meses"],
    "last year" : "añu caberu",
    "_%n hour ago_::_%n hours ago_" : ["hai %n hora","hai %n hores"],
    "_%n minute ago_::_%n minutes ago_" : ["hai %n minutu","hai %n minutos"],
    "seconds ago" : "hai segundos",
    "web services under your control" : "servicios web baxo'l to control",
    "File name contains at least one invalid character" : "El nome del ficheru contién polo menos un carácter non válidu",
    "App directory already exists" : "El direutoriu de l'aplicación yá esiste",
    "Can't create app folder. Please fix permissions. %s" : "Nun pue crease la carpeta de l'aplicación. Por favor, igua los permisos. %s",
    "No source specified when installing app" : "Nun s'especificó nenguna fonte al instalar app",
    "No href specified when installing app from http" : "Nun s'especificó href al instalar la app dende http",
    "No path specified when installing app from local file" : "Nun s'especificó camín dende un ficheru llocal al instalar l'aplicación",
    "Archives of type %s are not supported" : "Los ficheros de triba %s nun tán sofitaos",
    "Failed to open archive when installing app" : "Falló al abrir el ficheru al instalar l'aplicación",
    "App does not provide an info.xml file" : "L'aplicación nun apurre un ficheru info.xml",
    "App can't be installed because of not allowed code in the App" : "Nun pue instalase l'aplicación por causa d'un códigu non permitíu na App",
    "App can't be installed because it is not compatible with this version of ownCloud" : "Nun pue instalase l'aplicación porque nun ye compatible con esta versión d'ownCloud.",
    "App can't be installed because it contains the <shipped>true</shipped> tag which is not allowed for non shipped apps" : "L'aplicación nun pue instalase porque contién la etiqueta <shipped>true</shipped> que nun ta permitida p'aplicaciones non distribuyíes",
    "Application is not enabled" : "L'aplicación nun ta habilitada",
    "Authentication error" : "Fallu d'autenticación",
    "Token expired. Please reload page." : "Token caducáu. Recarga la páxina.",
    "Unknown user" : "Usuariu desconocíu",
    "%s enter the database username." : "%s introducir l'usuariu de la base de datos.",
    "%s enter the database name." : "%s introducir nome de la base de datos.",
    "%s you may not use dots in the database name" : "%s nun pues usar puntos nel nome de la base de datos",
    "Oracle connection could not be established" : "Nun pudo afitase la conexón d'Oracle",
    "Oracle username and/or password not valid" : "Nome d'usuariu o contraseña d'Oracle non válidos",
    "DB Error: \"%s\"" : "Fallu BD: \"%s\"",
    "Offending command was: \"%s\"" : "Comandu infractor: \"%s\"",
    "You need to enter either an existing account or the administrator." : "Tienes d'inxertar una cuenta esistente o la del alministrador.",
    "Offending command was: \"%s\", name: %s, password: %s" : "El comandu infractor foi: \"%s\", nome: %s, contraseña: %s",
    "PostgreSQL username and/or password not valid" : "Nome d'usuariu o contraseña PostgreSQL non válidos",
    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X nun ta sofitáu y %s nun furrulará afayadizamente nesta plataforma. ¡Úsalu baxo'l to riesgu!",
    "For the best results, please consider using a GNU/Linux server instead." : "Pa los meyores resultaos, por favor considera l'usu d'un sirvidor GNU/Linux nel so llugar.",
    "Set an admin username." : "Afitar nome d'usuariu p'almin",
    "Set an admin password." : "Afitar contraseña p'almin",
    "Can't create or write into the data directory %s" : "Nun pue crease o escribir dientro los datos del direutoriu %s",
    "%s shared »%s« with you" : "%s compartió »%s« contigo",
    "Sharing %s failed, because the file does not exist" : "Compartir %s falló, porque'l ficheru nun esiste",
    "You are not allowed to share %s" : "Nun tienes permisu pa compartir %s",
    "Sharing %s failed, because the user %s does not exist" : "Compartir %s falló, yá que l'usuariu %s nun esiste",
    "Sharing %s failed, because the user %s is not a member of any groups that %s is a member of" : "Compartir %s falló, yá que l'usuariu %s nun ye miembru de nengún de los grupos de los que ye miembru %s",
    "Sharing %s failed, because this item is already shared with %s" : "Compartir %s falló, porque esti elementu yá ta compartiéndose con %s",
    "Sharing %s failed, because the group %s does not exist" : "Compartir %s falló, porque'l grupu %s nun esiste",
    "Sharing %s failed, because %s is not a member of the group %s" : "Compartir %s falló, porque %s nun ye miembru del grupu %s",
    "You need to provide a password to create a public link, only protected links are allowed" : "Necesites apurrir una contraseña pa crear un enllaz públicu, namái tan permitíos los enllaces protexíos",
    "Sharing %s failed, because sharing with links is not allowed" : "Compartir %s falló, porque nun se permite compartir con enllaces",
    "Share type %s is not valid for %s" : "La triba de compartición %s nun ye válida pa %s",
    "Setting permissions for %s failed, because the permissions exceed permissions granted to %s" : "Falló dar permisos a %s, porque los permisos son mayores que los otorgaos a %s",
    "Setting permissions for %s failed, because the item was not found" : "Falló dar permisos a %s, porque l'elementu nun s'atopó",
    "Cannot set expiration date. Shares cannot expire later than %s after they have been shared" : "Nun pue afitase la data de caducidá. Ficheros compartíos nun puen caducar dempués de %s de compartise",
    "Cannot set expiration date. Expiration date is in the past" : "Nun pue afitase la data d'espiración. La data d'espiración ta nel pasáu",
    "Sharing backend %s must implement the interface OCP\\Share_Backend" : "El motor compartíu %s tien d'implementar la interfaz OCP\\Share_Backend",
    "Sharing backend %s not found" : "Nun s'alcontró'l botón de compartición %s",
    "Sharing backend for %s not found" : "Nun s'alcontró'l botón de partición pa %s",
    "Sharing %s failed, because the permissions exceed permissions granted to %s" : "Compartir %s falló, porque los permisos perpasen los otorgaos a %s",
    "Sharing %s failed, because resharing is not allowed" : "Compartir %s falló, porque nun se permite la re-compartición",
    "Sharing %s failed, because the sharing backend for %s could not find its source" : "Compartir %s falló porque'l motor compartíu pa %s podría nun atopar el so orixe",
    "Sharing %s failed, because the file could not be found in the file cache" : "Compartir %s falló, yá que'l ficheru nun pudo atopase na caché de ficheru",
    "Could not find category \"%s\"" : "Nun pudo alcontrase la estaya \"%s.\"",
    "Apps" : "Aplicaciones",
    "A valid username must be provided" : "Tien d'apurrise un nome d'usuariu válidu",
    "A valid password must be provided" : "Tien d'apurrise una contraseña válida",
    "The username is already being used" : "El nome d'usuariu yá ta usándose",
    "No database drivers (sqlite, mysql, or postgresql) installed." : "Nun hai controladores de bases de datos  (sqlite, mysql, o postgresql)",
    "Cannot write into \"config\" directory" : "Nun pue escribise nel direutoriu \"config\"",
    "Cannot write into \"apps\" directory" : "Nun pue escribise nel direutoriu \"apps\"",
    "This can usually be fixed by %sgiving the webserver write access to the apps directory%s or disabling the appstore in the config file." : "Esto pue iguase %sdando permisos d'escritura al sirvidor Web nel direutoriu%s d'apps o deshabilitando la tienda d'apps nel ficheru de configuración.",
    "Cannot create \"data\" directory (%s)" : "Nun pue crease'l direutoriu \"data\" (%s)",
    "This can usually be fixed by <a href=\"%s\" target=\"_blank\">giving the webserver write access to the root directory</a>." : "Esto pue iguase davezu <a href=\"%s\" target=\"_blank\">dándo-y accesu d'escritura al direutoriu raigañu</a>.",
    "Permissions can usually be fixed by %sgiving the webserver write access to the root directory%s." : "Davezu los permisos puen iguase %sdándo-y al sirvidor web accesu d'escritura al direutoriu raigañu%s.",
    "Setting locale to %s failed" : "Falló l'activación del idioma %s",
    "Please install one of these locales on your system and restart your webserver." : "Instala ún d'estos locales nel to sistema y reanicia'l sirvidor web",
    "Please ask your server administrator to install the module." : "Por favor, entrúga-y al to alministrador del sirvidor pa instalar el módulu.",
    "PHP module %s not installed." : "Nun ta instaláu'l módulu PHP %s",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Dablemente esto seya culpa d'un caché o acelerador, como por exemplu Zend OPcache o eAccelerator.",
    "PHP modules have been installed, but they are still listed as missing?" : "Instaláronse los módulos PHP, ¿pero tán entá llistaos como faltantes?",
    "Please ask your server administrator to restart the web server." : "Por favor, entruga al to alministrador pa reaniciar el sirvidor web.",
    "PostgreSQL >= 9 required" : "PostgreSQL >= 9 requeríu",
    "Please upgrade your database version" : "Por favor, anueva la versión de la to base de datos",
    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Por favor, camuda los permisos a 0770 pa que'l direutoriu nun pueda llistase por otros usuarios.",
    "Data directory (%s) is readable by other users" : "El direutoriu de datos (%s) ye llexible por otros usuarios",
    "Data directory (%s) is invalid" : "Ye inválidu'l direutoriu de datos (%s)",
    "Please check that the data directory contains a file \".ocdata\" in its root." : "Verifica que'l direutoriu de datos contién un ficheru \".ocdata\" nel direutoriu raigañu.",
    "Could not obtain lock type %d on \"%s\"." : "Nun pudo facese'l bloquéu %d en \"%s\".",
    "Storage not available" : "Almacenamientu non disponible"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-10.0.7.tgz: owncloud/lib/l10n/ast.js <==
OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "¡Nun pue escribise nel direutoriu \"config\"!",
    "This can usually be fixed by giving the webserver write access to the config directory" : "Davezu esto pue iguase dándo-y al sirvidor web accesu d'escritura al direutoriu de configuración",
    "See %s" : "Mira %s",
    "This can usually be fixed by %sgiving the webserver write access to the config directory%s." : "Davezu esto pue iguase %sdándo-y al sirvidor web accesu d'escritura al direutoriu de configuración%s.",
    "Sample configuration detected" : "Configuración d'amuesa detectada",
    "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Detectose que la configuración d'amuesa copiose. Esto pue encaboxar la instalación y dexala ensín soporte. Llee la documentación enantes de facer cambéos en config.php",
    "PHP %s or higher is required." : "Necesítase PHP %s o superior",
    "PHP with a version lower than %s is required." : "Necesítase una versión PHP anterior a %s",
    "%sbit or higher PHP required." : "Necesítase PHP %sbit o superior",
    "Following databases are supported: %s" : "Les siguientes bases de datos tan sofitaes: %s",
    "The command line tool %s could not be found" : "La ferramienta línea de comandu %s nun pudo alcontrase",
    "The library %s is not available." : "La librería %s nun ta disponible",
    "Library %s with a version higher than %s is required - available version %s." : "Necesítase una librería %s con ua versión superior a %s - versión disponible %s.",
    "Library %s with a version lower than %s is required - available version %s." : "Necesítase una librería %s con una versión anterior a %s - versión disponible %s.",
    "Following platforms are supported: %s" : "Les siguientes plataformes tan sofitaes: %s",
    "ownCloud %s or higher is required." : "Necesítase ownCloud %s o superior.",
    "ownCloud %s or lower is required." : "Necesítase ownCloud %s o anterior.",
    "Unknown filetype" : "Triba de ficheru desconocida",
    "Invalid image" : "Imaxe inválida",
    "today" : "güei",
    "yesterday" : "ayeri",
    "_%n day ago_::_%n days ago_" : ["hai %n día","hai %n díes"],
    "last month" : "mes caberu",
    "_%n month ago_::_%n months ago_" : ["hai %n mes","hai %n meses"],
    "last year" : "añu caberu",
    "_%n year ago_::_%n years ago_" : ["hai %n añu","hai %n años"],
    "_%n hour ago_::_%n hours ago_" : ["hai %n hora","hai %n hores"],
    "_%n minute ago_::_%n minutes ago_" : ["hai %n minutu","hai %n minutos"],
    "seconds ago" : "hai segundos",
    "Module with id: %s does not exist. Please enable it in your apps settings or contact your administrator." : "Nun esiste'l módulu con id:  %s . Por favor, activalu na configuración d'aplicaciones o contauta col alministrador.",
    "Builtin" : "Incorporáu",
    "None" : "Dengún",
    "Username and password" : "Nome d'usuariu y contraseña",
    "Username" : "Nome d'usuariu",
    "Password" : "Contraseña",
    "Log-in credentials, save in session" : "Credenciales d'aniciu de sesión, guardar na sesión",
    "Empty filename is not allowed" : "Nun s'almite un nome de ficheru baleru",
    "Dot files are not allowed" : "Ficheros Dot nun s'almiten",
    "4-byte characters are not supported in file names" : "Caracteres de 4-bytes nun tan soportaos en nomes de ficheros",
    "File name is a reserved word" : "El nome de ficheru ye una pallabra reservada",
    "File name contains at least one invalid character" : "El nome del ficheru contién polo menos un carácter non válidu",
    "File name is too long" : "El nome de ficheru ye demasiáu llargu",
    "App directory already exists" : "El direutoriu de l'aplicación yá esiste",
    "Can't create app folder. Please fix permissions. %s" : "Nun pue crease la carpeta de l'aplicación. Por favor, igua los permisos. %s",
    "Archive does not contain a directory named %s" : "L'archivu nun contien un directoriu nomáu %s",
    "No source specified when installing app" : "Nun s'especificó nenguna fonte al instalar app",
    "No href specified when installing app from http" : "Nun s'especificó href al instalar la app dende http",
    "No path specified when installing app from local file" : "Nun s'especificó camín dende un ficheru llocal al instalar l'aplicación",
    "Archives of type %s are not supported" : "Los ficheros de triba %s nun tán sofitaos",
    "Failed to open archive when installing app" : "Falló al abrir el ficheru al instalar l'aplicación",
    "App does not provide an info.xml file" : "L'aplicación nun apurre un ficheru info.xml",
    "App cannot be installed because appinfo file cannot be read." : "L'aplicación nun puede instalase porque nun se llee'l ficheru appinfo.",
    "Signature could not get checked. Please contact the app developer and check your admin screen." : "La firma nun puede ser evaluada . Por favor, póngase en contactu col desarrollador de l'aplicación y comprueba la so pantalla d'alministración .",
    "App can't be installed because of not allowed code in the App" : "Nun pue instalase l'aplicación por causa d'un códigu non permitíu na App",
    "App can't be installed because it is not compatible with this version of ownCloud" : "Nun pue instalase l'aplicación porque nun ye compatible con esta versión d'ownCloud.",
    "App can't be installed because it contains the <shipped>true</shipped> tag which is not allowed for non shipped apps" : "L'aplicación nun pue instalase porque contién la etiqueta <shipped>true</shipped> que nun ta permitida p'aplicaciones non distribuyíes",
    "App can't be installed because the version in info.xml is not the same as the version reported from the app store" : "L'aplicación nun puede instalase porque la versión en info.xml nun ye la mesma que la versión informada dende la tienda d'aplicaciones",
    "Apps" : "Aplicaciones",
    "General" : "Xeneral",
    "Storage" : "Almacenamientu",
    "Security" : "Seguridá",
    "Encryption" : "Cifráu",
    "Sharing" : "Compartiendo",
    "Search" : "Guetar",
    "Updates" : "Anovamientos",
    "%s enter the database username and name." : "%s introducir el nome d'usuariu y el nome de la base de datos .",
    "%s enter the database username." : "%s introducir l'usuariu de la base de datos.",
    "%s enter the database name." : "%s introducir nome de la base de datos.",
    "%s you may not use dots in the database name" : "%s nun pues usar puntos nel nome de la base de datos",
    "Oracle connection could not be established" : "Nun pudo afitase la conexón d'Oracle",
    "Oracle username and/or password not valid" : "Nome d'usuariu o contraseña d'Oracle non válidos",
    "DB Error: \"%s\"" : "Fallu BD: \"%s\"",
    "Offending command was: \"%s\"" : "Comandu infractor: \"%s\"",
    "You need to enter either an existing account or the administrator." : "Tienes d'inxertar una cuenta esistente o la del alministrador.",
    "Offending command was: \"%s\", name: %s, password: %s" : "El comandu infractor foi: \"%s\", nome: %s, contraseña: %s",
    "PostgreSQL username and/or password not valid" : "Nome d'usuariu o contraseña PostgreSQL non válidos",
    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X nun ta sofitáu y %s nun furrulará afayadizamente nesta plataforma. ¡Úsalu baxo'l to riesgu!",
    "For the best results, please consider using a GNU/Linux server instead." : "Pa los meyores resultaos, por favor considera l'usu d'un sirvidor GNU/Linux nel so llugar.",
    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Paez ser que la instancia %s ta executándose nun entornu de PHP 32 bits y el open_basedir configuróse en php.ini. Esto va dar llugar a problemes colos ficheros de más de 4 GB y nun ye nada recomendable.",
    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Por favor, desanicia la configuración open_basedir dientro la so php.ini o camude a PHP 64 bits.",
    "Set an admin username." : "Afitar nome d'usuariu p'almin",
    "Set an admin password." : "Afitar contraseña p'almin",
    "Can't create or write into the data directory %s" : "Nun pue crease o escribir dientro los datos del direutoriu %s",
    "Invalid Federated Cloud ID" : "Inválidu ID de Ñube Federada",
    "%s shared »%s« with you" : "%s compartió »%s« contigo",
    "%s via %s" : "%s via %s",
    "Sharing %s failed, because the backend does not allow shares from type %i" : "Compartir %s falló, por cuenta qu'el backend nun dexa acciones de tipu %i",
    "Sharing %s failed, because the file does not exist" : "Compartir %s falló, porque'l ficheru nun esiste",
    "You are not allowed to share %s" : "Nun tienes permisu pa compartir %s",
    "Sharing %s failed, because you can not share with yourself" : "Compartir %s falló, porque nun puede compartise contigo mesmu",
    "Sharing %s failed, because the user %s does not exist" : "Compartir %s falló, yá que l'usuariu %s nun esiste",
    "Sharing %s failed, because the user %s is not a member of any groups that %s is a member of" : "Compartir %s falló, yá que l'usuariu %s nun ye miembru de nengún de los grupos de los que ye miembru %s",
    "Sharing %s failed, because this item is already shared with %s" : "Compartir %s falló, porque esti elementu yá ta compartiéndose con %s",
    "Sharing %s failed, because this item is already shared with user %s" : "Compartir %s falló, porque esti elementu yá ta compartiéndose col usuariu %s",
    "Sharing %s failed, because the group %s does not exist" : "Compartir %s falló, porque'l grupu %s nun esiste",
    "Sharing %s failed, because %s is not a member of the group %s" : "Compartir %s falló, porque %s nun ye miembru del grupu %s",
    "You need to provide a password to create a public link, only protected links are allowed" : "Necesites apurrir una contraseña pa crear un enllaz públicu, namái tan permitíos los enllaces protexíos",
    "Sharing %s failed, because sharing with links is not allowed" : "Compartir %s falló, porque nun se permite compartir con enllaces",
    "Not allowed to create a federated share with the same user" : "Nun s'almite crear un recursu compartíu federáu col mesmu usuariu",
    "Sharing %s failed, could not find %s, maybe the server is currently unreachable." : "Compartir %s falló, nun pudo atopase %s, pue qu'el servidor nun seya anguaño algamable.",
    "Share type %s is not valid for %s" : "La triba de compartición %s nun ye válida pa %s",
    "Setting permissions for %s failed, because the permissions exceed permissions granted to %s" : "Falló dar permisos a %s, porque los permisos son mayores que los otorgaos a %s",
    "Setting permissions for %s failed, because the item was not found" : "Falló dar permisos a %s, porque l'elementu nun s'atopó",
    "Cannot set expiration date. Shares cannot expire later than %s after they have been shared" : "Nun pue afitase la data de caducidá. Ficheros compartíos nun puen caducar dempués de %s de compartise",
    "Cannot set expiration date. Expiration date is in the past" : "Nun pue afitase la data d'espiración. La data d'espiración ta nel pasáu",
    "Cannot clear expiration date. Shares are required to have an expiration date." : "Non puede desaniciar la fecha de caducidá. Compartir obliga a tener una fecha de caducidá.",
    "Sharing backend %s must implement the interface OCP\\Share_Backend" : "El motor compartíu %s tien d'implementar la interfaz OCP\\Share_Backend",
    "Sharing backend %s not found" : "Nun s'alcontró'l botón de compartición %s",
    "Sharing backend for %s not found" : "Nun s'alcontró'l botón de partición pa %s",
    "Sharing failed, because the user %s is the original sharer" : "Compartir falló, porque l'usuariu %s ye'l compartidor orixinal",
    "Sharing %s failed, because the permissions exceed permissions granted to %s" : "Compartir %s falló, porque los permisos perpasen los otorgaos a %s",
    "Sharing %s failed, because resharing is not allowed" : "Compartir %s falló, porque nun se permite la re-compartición",
    "Sharing %s failed, because the sharing backend for %s could not find its source" : "Compartir %s falló porque'l motor compartíu pa %s podría nun atopar el so orixe",
    "Sharing %s failed, because the file could not be found in the file cache" : "Compartir %s falló, yá que'l ficheru nun pudo atopase na caché de ficheru",
    "Cannot increase permissions of %s" : "Nun se pueden aumentar los permisos de %s",
    "Files can't be shared with delete permissions" : "Los ficheros nun pueden compartise con permisos desaniciaos",
    "Files can't be shared with create permissions" : "Los ficheros nun pueden compartise con crear permisos",
    "Expiration date is in the past" : "La data de caducidá ta nel pasáu.",
    "Cannot set expiration date more than %s days in the future" : "Nun pue afitase la data d'espiración más que  %s díes nel futuru",
    "Could not find category \"%s\"" : "Nun pudo alcontrase la estaya \"%s.\"",
    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "Namái tan permitíos los siguientes caráuteres nun nome d'usuariu: \"a-z\", \"A-Z\", \"0-9\", y \"_.@-'\"",
    "A valid username must be provided" : "Tien d'apurrise un nome d'usuariu válidu",
    "Username contains whitespace at the beginning or at the end" : "El nome d'usuario contién espacios en blancu al entamu o al final",
    "A valid password must be provided" : "Tien d'apurrise una contraseña válida",
    "The username is already being used" : "El nome d'usuariu yá ta usándose",
    "Login canceled by app" : "Aniciar sesión canceláu pola aplicación",
    "User disabled" : "Usuariu desactiváu",
    "Help" : "Ayuda",
    "Settings" : "Axustes",
    "Users" : "Usuarios",
    "App \"%s\" cannot be installed because the following dependencies are not fulfilled: %s" : "L'aplicación \"%s\" nun puede instalase porque les siguientes dependencies nun se cumplen: %s",
    "web services under your control" : "servicios web baxo'l to control",
    "File is currently busy, please try again later" : "Fichaeru ta ocupáu, por favor intentelo de nuevu más tarde",
    "Can't read file" : "Nun ye a lleese'l ficheru",
    "Application is not enabled" : "L'aplicación nun ta habilitada",
    "Authentication error" : "Fallu d'autenticación",
    "Token expired. Please reload page." : "Token caducáu. Recarga la páxina.",
    "Unknown user" : "Usuariu desconocíu",
    "No database drivers (sqlite, mysql, or postgresql) installed." : "Nun hai controladores de bases de datos  (sqlite, mysql, o postgresql)",
    "Cannot write into \"config\" directory" : "Nun pue escribise nel direutoriu \"config\"",
    "Cannot write into \"apps\" directory" : "Nun pue escribise nel direutoriu \"apps\"",
    "This can usually be fixed by %sgiving the webserver write access to the apps directory%s or disabling the appstore in the config file." : "Esto pue iguase %sdando permisos d'escritura al sirvidor Web nel direutoriu%s d'apps o deshabilitando la tienda d'apps nel ficheru de configuración.",
    "This can usually be fixed by <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">giving the webserver write access to the root directory</a>." : "Esto pue iguase davezu <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">dándo-y accesu d'escritura al direutoriu raigañu</a>.",
    "Permissions can usually be fixed by %sgiving the webserver write access to the root directory%s." : "Davezu los permisos puen iguase %sdándo-y al sirvidor web accesu d'escritura al direutoriu raigañu%s.",
    "Setting locale to %s failed" : "Falló l'activación del idioma %s",
    "Please install one of these locales on your system and restart your webserver." : "Instala ún d'estos locales nel to sistema y reanicia'l sirvidor web",
    "Please ask your server administrator to install the module." : "Por favor, entrúga-y al to alministrador del sirvidor pa instalar el módulu.",
    "PHP module %s not installed." : "Nun ta instaláu'l módulu PHP %s",
    "PHP setting \"%s\" is not set to \"%s\"." : "La configuración de PHP \"%s\" nun s'afita \"%s\".",
    "Adjusting this setting in php.ini will make ownCloud run again" : "Axuste de la configuración en php.ini va executar de nueves ownCloud",
    "mbstring.func_overload is set to \"%s\" instead of the expected value \"0\"" : "mbstring.func_overload afita \"%s\" en llugar del valor esperáu \"0\"",
    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini" : "Pa solucionar esti problema definíu <code>mbstring.func_overload</code>a <code>0</code> nel so php.ini",
    "libxml2 2.7.0 is at least required. Currently %s is installed." : "libxml2 2.7.0 ríquese siquier. Anguaño ta instaláu  %s.",
    "To fix this issue update your libxml2 version and restart your web server." : "Pa solucionar esti problema actualiza latso versión de libxml2 y reanicia'l to sirvidor web.",
    "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "PHP ta aparentemente configuráu pa desaniciar bloques de documentos en llinia. Esto va facer que delles aplicaciones principales nun tean accesibles.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Dablemente esto seya culpa d'un caché o acelerador, como por exemplu Zend OPcache o eAccelerator.",
    "PHP modules have been installed, but they are still listed as missing?" : "Instaláronse los módulos PHP, ¿pero tán entá llistaos como faltantes?",
    "Please ask your server administrator to restart the web server." : "Por favor, entruga al to alministrador pa reaniciar el sirvidor web.",
    "PostgreSQL >= 9 required" : "PostgreSQL >= 9 requeríu",
    "Please upgrade your database version" : "Por favor, anueva la versión de la to base de datos",
    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Por favor, camuda los permisos a 0770 pa que'l direutoriu nun pueda llistase por otros usuarios.",
    "Check the value of \"datadirectory\" in your configuration" : "Comprobar el valor del \"datadirectory\" na so configuración",
    "Please check that the data directory contains a file \".ocdata\" in its root." : "Verifica que'l direutoriu de datos contién un ficheru \".ocdata\" nel direutoriu raigañu.",
    "Could not obtain lock type %d on \"%s\"." : "Nun pudo facese'l bloquéu %d en \"%s\".",
    "Storage unauthorized. %s" : "Almacenamientu desautorizáu. %s",
    "Storage incomplete configuration. %s" : "Configuración d'almacenamientu incompleta. %s",
    "Storage connection error. %s" : "Fallu de conexón al almacenamientu. %s",
    "Storage connection timeout. %s" : "Tiempu escosao de conexón al almacenamientu. %s"
},
"nplurals=2; plural=(n != 1);");
